# voila-material

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/voila-dashboards/voila-material/stable?urlpath=voila)

Material design template for voila

## Installation

You can install it using pip:

```
pip install voila-material
```

Or using conda:

```
conda install -c conda-forge voila-material
```

## Usage

```
voila my_notebook.ipynb --template=material
```

Or for the dark theme:

```
voila my_notebook.ipynb --template=material --theme=dark
```

### Light theme

![screenshot](./images/material_tree.png)
![screenshot](./images/material_spinner.png)
![screenshot](./images/material_light.png)

### Dark theme

![screenshot](./images/material_dark_spinner.png)
![screenshot](./images/material_dark.png)
